@@ -184,7 +184,7 @@ class hexagon_grid:
         if self.area_threshold == None:
             area_threshold = (spacing*spacing)*0.33
             disolve_hexa = dissolve_polygon(final_hexa, area_threshold).geosolution
-            hexagon = gpd.overlay(data, disolve_hexa, how = 'union')
+            hexagon = gpd.overlay(gdf, disolve_hexa, how = 'union')
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
             check_topology(df)
             self.geosolution = df
@@ -193,7 +193,7 @@ class hexagon_grid:
         else:
             area_thres = (spacing*spacing)*self.area_threshold
             disolve_hexa = dissolve_polygon(final_hexa, area_thres).geosolution
-            hexagon = gpd.overlay(data, disolve_hexa, how = 'union')
+            hexagon = gpd.overlay(gdf, disolve_hexa, how = 'union')
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
             check_topology(df)
             self.geosolution = df
